@@ -3,82 +3,75 @@
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
    * http://www.jus.uio.no/sisu/SiSU/download
- * Description: Document skin sample prepared for Gutenberg Project (first used with "War and Peace") 
+ * Description: Document skin sample prepared for Gutenberg Project (first used with "War and Peace")
  * License: Same as SiSU see http://www.jus.uio.no/sisu
  * Notes: Site default appearance variables set in defaults.rb
      Generic site wide modifications set here scribe_skin.rb, and this file required by other "scribes" instead of defaults.rb
 =end
 module SiSU_Viz
   require "#{SiSU_lib}/defaults"
-  class Path
-    def root                                                                     # the only parameter that cannot be changed here
-      "./sisu/"  
+  class Skin
+    #% path
+    def path_root                                                                     # the only parameter that cannot be changed here
+      './sisu/'
     end
-    def rel
-      "../"
+    def path_rel
+      '../'
     end
-  end
-  class Url
-    #def hp # used by wmap, get rid of ie make it seek home instead
-    #  "http://www.gutenberg.net/"
-    #end
-    def home
+  #% url
+    def url_home
       'http://www.gutenberg.net'
     end
-    def txt                                                                      # text to go with url usually stripped url
+    def url_txt                                                                      # text to go with url usually stripped url
       'www.gutenberg.net'
     end
-  end
-  class Txt
-    def hp
+    #% txt
+    def txt_hp
       'www.gutenberg.net'
     end
-    def home
+    def txt_home
       'Gutenberg Project'
     end
-  end
-  class Icon
-    def home_button
+    #% icon
+    def icon_home_button
       'gutenberg.home.png'
     end
-    def home_banner
-      self.home_button
+    def icon_home_banner
+      icon_home_button
+    end
+    #% banner
+    def banner_home_button
+      %{<table summary="home button" border="0" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor=#{color_yellow_dark}><a href="#{url_home}">#{png_home}</a></td></tr></table>\n}
+    end
+    def banner_home_and_index_buttons
+      %{<table><tr><td width="20%"><table summary="home and index buttons" border="0" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor=#{color_yellow_dark}><a href="#{url_home}" target="_top">#{png_home}</a></td></tr></table></td><td width="60%"><center><center><table summary="buttons" border="1" cellpadding="3" cellspacing="0"><tr><td align="center" bgcolor="#f1e8de"><font face="arial" size="2"><a href="toc.html" target="_top">&nbsp;This&nbsp;text&nbsp;sub-&nbsp;<br />&nbsp;Table&nbsp;of&nbsp;Contents&nbsp;</a></font></td></tr></table></center></center></td><td width="20%">&nbsp;</td></tr></table>}
+    end
+    def banner_band
+      %{<table summary="band" border="0" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor=#{color_yellow_dark}><a href="#{url_home}" target="_top">#{png_home}</a>#{table_close}}
+    end
+    #% credits
+    def credits_splash
+      %{<table summary="credits" align="center"bgcolor="#ffffff"><tr><td><font color="black"><center><a href="http://www.gutenberg.net/"><img border="0" align="center" src="../_sisu/image_local/gutenberg_icon.png" alt="Gutenberg Project"><br />Courtesy of The Gutenberg Project</a><br />#{widget_sisu}</center></font></td></tr></table>}
     end
   end
-  class Banner
-    def home_button
-      %{<table summary="home button" border="0" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor=#{@color.yellow_dark}><a href="#{@url.home}">#{@png.home}</a></td></tr></table>\n}
-    end
-    def home_and_index_buttons
-      %{<table><tr><td width="20%"><table summary="home and index buttons" border="0" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor=#{@color.yellow_dark}><a href="#{@url.home}" target="_top">#{@png.home}</a></td></tr></table></td><td width="60%"><center><center><table summary="buttons" border="1" cellpadding="3" cellspacing="0"><tr><td align="center" bgcolor="#f1e8de"><font face="arial" size="2"><a href="toc.html" target="_top">&nbsp;This&nbsp;text&nbsp;sub-&nbsp;<br />&nbsp;Table&nbsp;of&nbsp;Contents&nbsp;</a></font></td></tr></table></center></center></td><td width="20%">&nbsp;</td></tr></table>}
-    end
-    def band
-      %{<table summary="band" border="0" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor=#{@color.yellow_dark}><a href="#{@url.home}" target="_top">#{@png.home}</a>#{@table.close}}
-    end
-  end
-  class Credits
-    def credits
-      %{<table summary="credits" align="center"bgcolor="#ffffff"><tr><td><font color="black"><center><a href="http://www.gutenberg.net/"><img border="0" align="center" src="../_sisu/image_local/gutenberg_icon.png" alt="Gutenberg Project"><br />Courtesy of The Gutenberg Project</a><br />#{@widget.sisu}</center></font></td></tr></table>}
-    end
-  end
-  class Tex
+  class TeX
     def header_center
-	    "\\chead{\\href{#{@url.home}}{www.gutenberg.net}}"
+	    "\\chead{\\href{#{@vz.url_home}}{www.gutenberg.net}}"
     end
     def home_url
-	    "\\href{#{@url.home}}{www.gutenberg.net}"
+	    "\\href{#{@vz.url_home}}{www.gutenberg.net}"
     end
     def home
-	    "\\href{#{@url.home}}{Gutenberg Project}"
+	    "\\href{#{@vz.url_home}}{Gutenberg Project}"
     end
     def owner_chapter
       "Document owner details"
     end
     def stmp
-	    "\\copyright Ralph Amissah, licence GPL 2 or later \\\\\n www.jus.uio.no/sisu/"
+	    "\\copyright Ralph Amissah, licence GPL \\\\\n www.jus.uio.no/sisu/"
     end
   end
-  class MetaV
+  class Inserts
     def insert1
 <<CONTENTS
 
